@@ -1,7 +1,7 @@
 package hcl
 
 import (
-	"io/ioutil"
+	"os"
 	"path"
 	"strings"
 
@@ -43,7 +43,7 @@ func ParseTerraformFromHCL(filename string) (*TerraformBlock, error) {
 func GetCurrentWorkspaceName(cwd string) string {
 	name := DefaultStateName // See https://github.com/hashicorp/terraform/blob/main/internal/backend/backend.go#L33
 
-	data, err := ioutil.ReadFile(path.Join(cwd, ".terraform/environment"))
+	data, err := os.ReadFile(path.Join(cwd, ".terraform/environment"))
 	if err != nil {
 		return name
 	}
